## 1.0.0 (2023-05-13)

### Feat

- Checking space
- Added simple compilation test
- Allow dynamically change sprites
- Added .gitignore
- Prepared test project

### Fix

- Generate required images
- Don't modify original setttings object
- Fixed size condition for repated blocks
- Create directory before image save attempt
- Fixed name conflict
- Replaced conflict class name
- Django 4.2 compatibility

### Refactor

- Removed unused code
- Remvoed old django version support
- Remvoed unused code
- Removed attributes support (not used, broken)
- Remved useless attributes for directly rendered scripts
- Template cleanup
